-- Thanks to Fenris_Wolf for rewriting the model loader code!
local MOD_ID = "FRUsedCars"
local MOD_NAME = "Filibuster Rhymes' Used Car Dealership"
local MOD_VERSION = "1.00"
local MOD_AUTHOR = "Filibuster Rhymes"

local dir = getDir(MOD_ID)



-- backwards compatibility
local vehicleLoader = loadStaticZomboidModel
if loadVehicleModel then vehicleLoader = loadVehicleModel end

-- Dont need to call this function manually, use loadVehicle() or loadWheel() below
-- If 'model' or 'texture' are nil, then 'name' is used, saving on retudnant typing.
-- However this expects a standard naming pattern of the files:
-- name is converted to "Vehicles_<NAME>"
-- model is converted to "/media/models/Vehicles_<MODEL>.txt"
-- texture is converted to "/media/textures/Vehicles/vehicle_<TEXTURE>.png"
-- if isVehicle is true, then texture is converted to "/media/textures/Vehicles/vehicle_<TEXTURE>shell.png"


--model loader test
local function loadModel(name, model, texture, isVehicle)
    if not model then model = name end
    if not texture then texture = name end
    --local textureSuffix = isVehicle and "shell.png" or ""
    local textureSuffix = isVehicle and "shell" or ""
    -- check which function we need to use to load models
    local loadFunction = isVehicle and vehicleLoader or loadStaticZomboidModel
    loadFunction("Vehicles_" .. name,
        dir.."/media/models/Vehicles_" .. model .. ".txt",
        "/Vehicles/vehicle_" .. string.lower(texture) .. textureSuffix)
end

-- this function loads the vehicle model and texture,
local function loadVehicle(name, model, texture)
    loadModel(name, model, texture, true)
end

-- this function loads the wheel models and texture,
local function loadWheel(name, model, texture)
    loadModel(name, model, texture, false)
end


-----------------------------------------------------------
-- add new vehicles and wheels below here:
-----------------------------------------------------------

Events.OnInitWorld.Add(function()
    loadVehicle("GTO")
    loadVehicle("ElCamino68")
    loadVehicle("ElCamino70")
    loadVehicle("Charger")
    loadVehicle("FordFalcon")
    loadVehicle("PursuitSpecial")
    -- trans am defaults to blue shell,  so manually define it
    loadVehicle("77TransAm", nil, "77transamblue")
    loadVehicle("85CrownVic")
    loadVehicle("85CrownVicWag")
    loadVehicle("71Impala")
    loadVehicle("68Wildcat")
    loadVehicle("Brougham")

    loadVehicle("85CrownVicRNG")
    loadVehicle("85CrownVicPD")
    loadVehicle("Yugo")
    --C10LB/C10SB use the C10 shell, so manually define it
    loadVehicle("C10LB", nil, "c10")
    loadVehicle("C10SB", nil, "c10")
	loadVehicle("C10Utility")
	loadVehicle("C10UtilityLights", nil, "c10utilitymccoyshell")


    loadVehicle("Suburban")

    -- shell name for the dodge ram doesnt follow pattern so manually define it
    loadVehicle("DodgeRamSB", nil, "dodgeram")
    loadVehicle("DodgeRamLB", nil, "dodgeram")

    loadVehicle("BlazerPD")
    loadVehicle("Blazer")
    loadVehicle("Chevelle")
    loadVehicle("91CRX")
	loadVehicle("HMMWVHardTop")
	loadVehicle("HMMWVPrimeMover")
	loadVehicle("M151Canvas")
	
	loadVehicle("MovingTruck")
	loadVehicle("IsuzuBox")
	loadVehicle("IsuzuBoxMcCoy")
	loadVehicle("AstroVan")
	loadVehicle("Volvo244")
	loadVehicle("Pinto")

    -- add the wheels
    loadWheel("WheelFRL1")
    loadWheel("WheelFRL2")
    loadWheel("WheelFRS1")
	loadWheel("WheelFRS2")
	loadWheel("WheelFRS3")
    loadWheel("WheelFR01")
    loadWheel("WheelFR03")
    loadWheel("WheelFR04")
    loadWheel("WheelFR05")
    loadWheel("WheelFRPD1")
    loadWheel("WheelFRLPD1")
	loadWheel("WheelMIL")
	loadWheel("WheelMIL2")
    loadWheel("WheelFRTrans")

	print("Mod Loaded: " .. MOD_NAME .. " by " .. MOD_AUTHOR .. " (v" .. MOD_VERSION .. ")")
end)
